const state = {
    customers: [],
    filtered: [],
    selectedCustomer: null
}

const getters = {
    getCustomers(state) {
        return state.filtered.length === 0 ? state.customers : state.filtered
    },
    hasSelectedCustomer(state) {
        return !!state.selectedCustomer
    },
    getSelectedCustomer(state) {
        return state.selectedCustomer
    }
}

const mutations = {
    pushCustomers(state, payload) {
        state.customers = [...payload.customers]
    },
    selectCustomer(state, payload) {
        state.selectedCustomer = payload.customer
    },
    applyCustomersFilter(state, payload) {
        state.filtered = payload
    }
}

const actions = {
    fetchCustomers({ commit, dispatch }) {
        return new Promise((resolve, reject) => {
            let pos = new openerp.web.Model('eiru.pos')
            pos.call('get_customers').then(response => {
                commit('pushCustomers', {
                    customers: response
                })

                dispatch('loaded', {
                    module: 'customers'
                })

                resolve()
            }).fail(error => {
                console.log(error)
                reject(error)
            })
        })
    },
    selectCustomer({ commit }, payload) {
        commit('selectCustomer', {
            customer: payload
        })
    },
    filterCustomers({ commit }, payload) {
        commit('applyCustomersFilter', payload)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}